@@ -79,10 +79,11 @@ from .phonemetadata import REGION_CODE_FOR_NON_GEO_ENTITY, NumberFormat, PhoneNu
 # Functionality
 from .asyoutypeformatter import AsYouTypeFormatter
 from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
-                              SUPPORTED_SHORT_REGIONS, UNKNOWN_REGION, COUNTRY_CODES_FOR_NON_GEO_REGIONS,
+                              UNKNOWN_REGION, COUNTRY_CODES_FOR_NON_GEO_REGIONS,
                               NON_DIGITS_PATTERN,
                               MatchType, NumberParseException, PhoneNumberFormat,
                               PhoneNumberType, ValidationResult,
+                              can_be_internationally_dialled,
                               convert_alpha_characters_in_number,
                               country_code_for_region,
                               country_code_for_valid_region,
@@ -98,28 +99,37 @@ from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
                               format_number,
                               format_out_of_country_calling_number,
                               format_out_of_country_keeping_alpha_chars,
+                              invalid_example_number,
                               is_alpha_number,
                               is_nanpa_country,
                               is_number_match,
+                              is_number_geographical,
+                              is_number_type_geographical,
                               is_possible_number,
+                              is_possible_number_for_type,
+                              is_possible_number_for_type_with_reason,
                               is_possible_number_string,
                               is_possible_number_with_reason,
                               is_valid_number,
                               is_valid_number_for_region,
                               length_of_geographical_area_code,
                               length_of_national_destination_code,
-                              country_mobile_token,
                               national_significant_number,
                               ndd_prefix_for_region,
                               normalize_digits_only,
+                              normalize_diallable_chars_only,
                               number_type,
                               parse,
                               region_code_for_country_code,
                               region_codes_for_country_code,
                               region_code_for_number,
+                              supported_calling_codes,
+                              supported_types_for_region,
+                              supported_types_for_non_geo_entity,
                               truncate_too_long_number,
                               is_mobile_number_portable_region,)
-from .shortnumberinfo import (ShortNumberCost,
+from .shortnumberinfo import (SUPPORTED_SHORT_REGIONS,
+                              ShortNumberCost,
                               is_possible_short_number_for_region,
                               is_possible_short_number,
                               is_valid_short_number_for_region,
@@ -128,24 +138,26 @@ from .shortnumberinfo import (ShortNumberCost,
                               expected_cost,
                               connects_to_emergency_number,
                               is_emergency_number,
-                              is_carrier_specific)
+                              is_carrier_specific,
+                              is_carrier_specific_for_region,
+                              is_sms_service_for_region)
 from .phonenumbermatcher import PhoneNumberMatch, PhoneNumberMatcher, Leniency
 
 
 # Version number is taken from the upstream libphonenumber version
 # together with an indication of the version of the Python-specific code.
-__version__ = "7.0.1"
+__version__ = "8.12.32"
 
 __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'REGION_CODE_FOR_NON_GEO_ENTITY', 'NumberFormat', 'PhoneNumberDesc', 'PhoneMetadata',
            'AsYouTypeFormatter',
            # items from phonenumberutil.py
            'COUNTRY_CODE_TO_REGION_CODE', 'SUPPORTED_REGIONS',
-           'SUPPORTED_SHORT_REGIONS', 'UNKNOWN_REGION', 'COUNTRY_CODES_FOR_NON_GEO_REGIONS',
+           'UNKNOWN_REGION', 'COUNTRY_CODES_FOR_NON_GEO_REGIONS',
            'NON_DIGITS_PATTERN',
            'MatchType', 'NumberParseException', 'PhoneNumberFormat',
            'PhoneNumberType', 'ValidationResult',
-           'choose_formatting_pattern_for_number',
+           'can_be_internationally_dialled',
            'convert_alpha_characters_in_number',
            'country_code_for_region',
            'country_code_for_valid_region',
@@ -157,15 +169,19 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'format_in_original_format',
            'format_national_number_with_carrier_code',
            'format_national_number_with_preferred_carrier_code',
-           'format_nsn_using_pattern',
            'format_number_for_mobile_dialing',
            'format_number',
            'format_out_of_country_calling_number',
            'format_out_of_country_keeping_alpha_chars',
+           'invalid_example_number',
            'is_alpha_number',
            'is_nanpa_country',
+           'is_number_geographical',
+           'is_number_type_geographical',
            'is_number_match',
            'is_possible_number',
+           'is_possible_number_for_type',
+           'is_possible_number_for_type_with_reason',
            'is_possible_number_string',
            'is_possible_number_with_reason',
            'is_valid_number',
@@ -175,15 +191,20 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'national_significant_number',
            'ndd_prefix_for_region',
            'normalize_digits_only',
+           'normalize_diallable_chars_only',
            'number_type',
            'parse',
            'region_code_for_country_code',
            'region_codes_for_country_code',
            'region_code_for_number',
+           'supported_calling_codes',
+           'supported_types_for_region',
+           'supported_types_for_non_geo_entity',
            'truncate_too_long_number',
            'is_mobile_number_portable_region',
            # end of items from phonenumberutil.py
            # items from shortnumberinfo.py
+           'SUPPORTED_SHORT_REGIONS',
            'ShortNumberCost',
            'is_possible_short_number_for_region',
            'is_possible_short_number',
@@ -194,6 +215,8 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'connects_to_emergency_number',
            'is_emergency_number',
            'is_carrier_specific',
+           'is_carrier_specific_for_region',
+           'is_sms_service_for_region',
            # end of items from shortnumberinfo.py
            'PhoneNumberMatch', 'PhoneNumberMatcher', 'Leniency',
            ]
